/* DynamicToolbar.c generated by valac 0.56.18, the Vala compiler
 * generated from DynamicToolbar.vala, do not modify */

/*
* Copyright (c) 2016 Felipe Escoto (https://github.com/Philip-Scott/Spice-up)
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public
* License as published by the Free Software Foundation; either
* version 2 of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* General Public License for more details.
*
* You should have received a copy of the GNU General Public
* License along with this program; if not, write to the
* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
* Boston, MA 02111-1307, USA.
*
* Authored by: Felipe Escoto <felescoto95@hotmail.com>
*/

#include <gtk/gtk.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <glib.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define SPICE_TYPE_DYNAMIC_TOOLBAR (spice_dynamic_toolbar_get_type ())
#define SPICE_DYNAMIC_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_DYNAMIC_TOOLBAR, SpiceDynamicToolbar))
#define SPICE_DYNAMIC_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_DYNAMIC_TOOLBAR, SpiceDynamicToolbarClass))
#define SPICE_IS_DYNAMIC_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_DYNAMIC_TOOLBAR))
#define SPICE_IS_DYNAMIC_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_DYNAMIC_TOOLBAR))
#define SPICE_DYNAMIC_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_DYNAMIC_TOOLBAR, SpiceDynamicToolbarClass))

typedef struct _SpiceDynamicToolbar SpiceDynamicToolbar;
typedef struct _SpiceDynamicToolbarClass SpiceDynamicToolbarClass;
typedef struct _SpiceDynamicToolbarPrivate SpiceDynamicToolbarPrivate;

#define SPICE_TYPE_SLIDE_MANAGER (spice_slide_manager_get_type ())
#define SPICE_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManager))
#define SPICE_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))
#define SPICE_IS_SLIDE_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_IS_SLIDE_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE_MANAGER))
#define SPICE_SLIDE_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE_MANAGER, SpiceSlideManagerClass))

typedef struct _SpiceSlideManager SpiceSlideManager;
typedef struct _SpiceSlideManagerClass SpiceSlideManagerClass;

#define SPICE_WIDGETS_TYPE_TOOLBAR (spice_widgets_toolbar_get_type ())
#define SPICE_WIDGETS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbar))
#define SPICE_WIDGETS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))
#define SPICE_WIDGETS_IS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_IS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TOOLBAR))
#define SPICE_WIDGETS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TOOLBAR, SpiceWidgetsToolbarClass))

typedef struct _SpiceWidgetsToolbar SpiceWidgetsToolbar;
typedef struct _SpiceWidgetsToolbarClass SpiceWidgetsToolbarClass;
enum  {
	SPICE_DYNAMIC_TOOLBAR_0_PROPERTY,
	SPICE_DYNAMIC_TOOLBAR_NUM_PROPERTIES
};
static GParamSpec* spice_dynamic_toolbar_properties[SPICE_DYNAMIC_TOOLBAR_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define SPICE_WIDGETS_TYPE_TEXT_TOOLBAR (spice_widgets_text_toolbar_get_type ())
#define SPICE_WIDGETS_TEXT_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbar))
#define SPICE_WIDGETS_TEXT_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbarClass))
#define SPICE_WIDGETS_IS_TEXT_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR))
#define SPICE_WIDGETS_IS_TEXT_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR))
#define SPICE_WIDGETS_TEXT_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_TEXT_TOOLBAR, SpiceWidgetsTextToolbarClass))

typedef struct _SpiceWidgetsTextToolbar SpiceWidgetsTextToolbar;
typedef struct _SpiceWidgetsTextToolbarClass SpiceWidgetsTextToolbarClass;

#define SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR (spice_widgets_shape_toolbar_get_type ())
#define SPICE_WIDGETS_SHAPE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbar))
#define SPICE_WIDGETS_SHAPE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbarClass))
#define SPICE_WIDGETS_IS_SHAPE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR))
#define SPICE_WIDGETS_IS_SHAPE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR))
#define SPICE_WIDGETS_SHAPE_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_SHAPE_TOOLBAR, SpiceWidgetsShapeToolbarClass))

typedef struct _SpiceWidgetsShapeToolbar SpiceWidgetsShapeToolbar;
typedef struct _SpiceWidgetsShapeToolbarClass SpiceWidgetsShapeToolbarClass;

#define SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR (spice_widgets_image_toolbar_get_type ())
#define SPICE_WIDGETS_IMAGE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR, SpiceWidgetsImageToolbar))
#define SPICE_WIDGETS_IMAGE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR, SpiceWidgetsImageToolbarClass))
#define SPICE_WIDGETS_IS_IMAGE_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR))
#define SPICE_WIDGETS_IS_IMAGE_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR))
#define SPICE_WIDGETS_IMAGE_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_IMAGE_TOOLBAR, SpiceWidgetsImageToolbarClass))

typedef struct _SpiceWidgetsImageToolbar SpiceWidgetsImageToolbar;
typedef struct _SpiceWidgetsImageToolbarClass SpiceWidgetsImageToolbarClass;

#define SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR (spice_widgets_canvas_toolbar_get_type ())
#define SPICE_WIDGETS_CANVAS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbar))
#define SPICE_WIDGETS_CANVAS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbarClass))
#define SPICE_WIDGETS_IS_CANVAS_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR))
#define SPICE_WIDGETS_IS_CANVAS_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR))
#define SPICE_WIDGETS_CANVAS_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_CANVAS_TOOLBAR, SpiceWidgetsCanvasToolbarClass))

typedef struct _SpiceWidgetsCanvasToolbar SpiceWidgetsCanvasToolbar;
typedef struct _SpiceWidgetsCanvasToolbarClass SpiceWidgetsCanvasToolbarClass;

#define SPICE_WIDGETS_TYPE_COMMON_TOOLBAR (spice_widgets_common_toolbar_get_type ())
#define SPICE_WIDGETS_COMMON_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbar))
#define SPICE_WIDGETS_COMMON_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbarClass))
#define SPICE_WIDGETS_IS_COMMON_TOOLBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR))
#define SPICE_WIDGETS_IS_COMMON_TOOLBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR))
#define SPICE_WIDGETS_COMMON_TOOLBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_WIDGETS_TYPE_COMMON_TOOLBAR, SpiceWidgetsCommonToolbarClass))

typedef struct _SpiceWidgetsCommonToolbar SpiceWidgetsCommonToolbar;
typedef struct _SpiceWidgetsCommonToolbarClass SpiceWidgetsCommonToolbarClass;

#define SPICE_TYPE_WINDOW (spice_window_get_type ())
#define SPICE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_WINDOW, SpiceWindow))
#define SPICE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_WINDOW, SpiceWindowClass))
#define SPICE_IS_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_WINDOW))
#define SPICE_IS_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_WINDOW))
#define SPICE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_WINDOW, SpiceWindowClass))

typedef struct _SpiceWindow SpiceWindow;
typedef struct _SpiceWindowClass SpiceWindowClass;

#define SPICE_SERVICES_TYPE_HISTORY_MANAGER (spice_services_history_manager_get_type ())
#define SPICE_SERVICES_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManager))
#define SPICE_SERVICES_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))
#define SPICE_SERVICES_IS_HISTORY_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_IS_HISTORY_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_SERVICES_TYPE_HISTORY_MANAGER))
#define SPICE_SERVICES_HISTORY_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_SERVICES_TYPE_HISTORY_MANAGER, SpiceServicesHistoryManagerClass))

typedef struct _SpiceServicesHistoryManager SpiceServicesHistoryManager;
typedef struct _SpiceServicesHistoryManagerClass SpiceServicesHistoryManagerClass;

#define SPICE_TYPE_CANVAS_ITEM (spice_canvas_item_get_type ())
#define SPICE_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItem))
#define SPICE_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))
#define SPICE_IS_CANVAS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_IS_CANVAS_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_CANVAS_ITEM))
#define SPICE_CANVAS_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_CANVAS_ITEM, SpiceCanvasItemClass))

typedef struct _SpiceCanvasItem SpiceCanvasItem;
typedef struct _SpiceCanvasItemClass SpiceCanvasItemClass;
typedef struct _SpiceSlideManagerPrivate SpiceSlideManagerPrivate;

#define SPICE_TYPE_SLIDE (spice_slide_get_type ())
#define SPICE_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_SLIDE, SpiceSlide))
#define SPICE_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_SLIDE, SpiceSlideClass))
#define SPICE_IS_SLIDE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_SLIDE))
#define SPICE_IS_SLIDE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_SLIDE))
#define SPICE_SLIDE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_SLIDE, SpiceSlideClass))

typedef struct _SpiceSlide SpiceSlide;
typedef struct _SpiceSlideClass SpiceSlideClass;

#define SPICE_TYPE_TEXT_ITEM (spice_text_item_get_type ())
#define SPICE_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_TEXT_ITEM, SpiceTextItem))
#define SPICE_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_TEXT_ITEM, SpiceTextItemClass))
#define SPICE_IS_TEXT_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_TEXT_ITEM))
#define SPICE_IS_TEXT_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_TEXT_ITEM))
#define SPICE_TEXT_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_TEXT_ITEM, SpiceTextItemClass))

typedef struct _SpiceTextItem SpiceTextItem;
typedef struct _SpiceTextItemClass SpiceTextItemClass;

#define SPICE_TYPE_COLOR_ITEM (spice_color_item_get_type ())
#define SPICE_COLOR_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_COLOR_ITEM, SpiceColorItem))
#define SPICE_COLOR_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_COLOR_ITEM, SpiceColorItemClass))
#define SPICE_IS_COLOR_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_COLOR_ITEM))
#define SPICE_IS_COLOR_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_COLOR_ITEM))
#define SPICE_COLOR_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_COLOR_ITEM, SpiceColorItemClass))

typedef struct _SpiceColorItem SpiceColorItem;
typedef struct _SpiceColorItemClass SpiceColorItemClass;

#define SPICE_TYPE_IMAGE_ITEM (spice_image_item_get_type ())
#define SPICE_IMAGE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPICE_TYPE_IMAGE_ITEM, SpiceImageItem))
#define SPICE_IMAGE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPICE_TYPE_IMAGE_ITEM, SpiceImageItemClass))
#define SPICE_IS_IMAGE_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPICE_TYPE_IMAGE_ITEM))
#define SPICE_IS_IMAGE_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPICE_TYPE_IMAGE_ITEM))
#define SPICE_IMAGE_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPICE_TYPE_IMAGE_ITEM, SpiceImageItemClass))

typedef struct _SpiceImageItem SpiceImageItem;
typedef struct _SpiceImageItemClass SpiceImageItemClass;

struct _SpiceDynamicToolbar {
	GtkBox parent_instance;
	SpiceDynamicToolbarPrivate * priv;
};

struct _SpiceDynamicToolbarClass {
	GtkBoxClass parent_class;
};

struct _SpiceDynamicToolbarPrivate {
	gchar* TEXT;
	gchar* IMAGE;
	gchar* SHAPE;
	gchar* CANVAS;
	SpiceSlideManager* manager;
	GtkStack* stack;
	SpiceWidgetsToolbar* text_bar;
	SpiceWidgetsToolbar* shape_bar;
	SpiceWidgetsToolbar* image_bar;
	SpiceWidgetsToolbar* canvas_bar;
	SpiceWidgetsToolbar* common_bar;
};

struct _SpiceSlideManager {
	GObject parent_instance;
	SpiceSlideManagerPrivate * priv;
	gboolean making_new_slide;
	SpiceSlide* end_presentation_slide;
	SpiceSlide* preview_slide_;
	SpiceSlide* checkpoint;
};

struct _SpiceSlideManagerClass {
	GObjectClass parent_class;
};

static gint SpiceDynamicToolbar_private_offset;
static gpointer spice_dynamic_toolbar_parent_class = NULL;

VALA_EXTERN GType spice_dynamic_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceDynamicToolbar, g_object_unref)
VALA_EXTERN GType spice_slide_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlideManager, g_object_unref)
VALA_EXTERN GType spice_widgets_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsToolbar, g_object_unref)
VALA_EXTERN SpiceDynamicToolbar* spice_dynamic_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceDynamicToolbar* spice_dynamic_toolbar_construct (GType object_type,
                                                      SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsTextToolbar* spice_widgets_text_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsTextToolbar* spice_widgets_text_toolbar_construct (GType object_type,
                                                               SpiceSlideManager* slide_manager);
VALA_EXTERN GType spice_widgets_text_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsTextToolbar, g_object_unref)
VALA_EXTERN SpiceWidgetsShapeToolbar* spice_widgets_shape_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsShapeToolbar* spice_widgets_shape_toolbar_construct (GType object_type,
                                                                 SpiceSlideManager* slide_manager);
VALA_EXTERN GType spice_widgets_shape_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsShapeToolbar, g_object_unref)
VALA_EXTERN SpiceWidgetsImageToolbar* spice_widgets_image_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsImageToolbar* spice_widgets_image_toolbar_construct (GType object_type,
                                                                 SpiceSlideManager* slide_manager);
VALA_EXTERN GType spice_widgets_image_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsImageToolbar, g_object_unref)
VALA_EXTERN SpiceWidgetsCanvasToolbar* spice_widgets_canvas_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsCanvasToolbar* spice_widgets_canvas_toolbar_construct (GType object_type,
                                                                   SpiceSlideManager* slide_manager);
VALA_EXTERN GType spice_widgets_canvas_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsCanvasToolbar, g_object_unref)
VALA_EXTERN SpiceWidgetsCommonToolbar* spice_widgets_common_toolbar_new (SpiceSlideManager* slide_manager);
VALA_EXTERN SpiceWidgetsCommonToolbar* spice_widgets_common_toolbar_construct (GType object_type,
                                                                   SpiceSlideManager* slide_manager);
VALA_EXTERN GType spice_widgets_common_toolbar_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWidgetsCommonToolbar, g_object_unref)
VALA_EXTERN GType spice_window_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceWindow, g_object_unref)
VALA_EXTERN SpiceWindow* spice_slide_manager_get_window (SpiceSlideManager* self);
VALA_EXTERN GType spice_services_history_manager_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceServicesHistoryManager, g_object_unref)
VALA_EXTERN SpiceServicesHistoryManager* spice_window_get_history_manager (SpiceWindow* self);
VALA_EXTERN GType spice_canvas_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceCanvasItem, g_object_unref)
static void __lambda117_ (SpiceDynamicToolbar* self,
                   SpiceCanvasItem* i);
VALA_EXTERN void spice_dynamic_toolbar_item_selected (SpiceDynamicToolbar* self,
                                          SpiceCanvasItem* item,
                                          gboolean new_item);
static void ___lambda117__spice_services_history_manager_action_called (SpiceServicesHistoryManager* _sender,
                                                                 SpiceCanvasItem* item,
                                                                 gpointer self);
VALA_EXTERN void spice_widgets_toolbar_select_item (SpiceWidgetsToolbar* self,
                                        SpiceCanvasItem* item_,
                                        gboolean new_item);
VALA_EXTERN GType spice_slide_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceSlide, g_object_unref)
VALA_EXTERN GType spice_text_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceTextItem, g_object_unref)
VALA_EXTERN GType spice_color_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceColorItem, g_object_unref)
VALA_EXTERN GType spice_image_item_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (SpiceImageItem, g_object_unref)
static void spice_dynamic_toolbar_finalize (GObject * obj);
static GType spice_dynamic_toolbar_get_type_once (void);

static inline gpointer
spice_dynamic_toolbar_get_instance_private (SpiceDynamicToolbar* self)
{
	return G_STRUCT_MEMBER_P (self, SpiceDynamicToolbar_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 38 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 323 "DynamicToolbar.c"
}

static void
__lambda117_ (SpiceDynamicToolbar* self,
              SpiceCanvasItem* i)
{
#line 64 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	spice_dynamic_toolbar_item_selected (self, i, FALSE);
#line 332 "DynamicToolbar.c"
}

static void
___lambda117__spice_services_history_manager_action_called (SpiceServicesHistoryManager* _sender,
                                                            SpiceCanvasItem* item,
                                                            gpointer self)
{
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	__lambda117_ ((SpiceDynamicToolbar*) self, item);
#line 342 "DynamicToolbar.c"
}

SpiceDynamicToolbar*
spice_dynamic_toolbar_construct (GType object_type,
                                 SpiceSlideManager* slide_manager)
{
	SpiceDynamicToolbar * self = NULL;
	SpiceSlideManager* _tmp0_;
	GtkStack* _tmp1_;
	GtkStack* _tmp2_;
	GtkStack* _tmp3_;
	GtkStyleContext* _tmp4_;
	GtkStyleContext* _tmp5_;
	SpiceWidgetsTextToolbar* _tmp6_;
	SpiceWidgetsShapeToolbar* _tmp7_;
	SpiceWidgetsImageToolbar* _tmp8_;
	SpiceWidgetsCanvasToolbar* _tmp9_;
	SpiceWidgetsCommonToolbar* _tmp10_;
	GtkStack* _tmp11_;
	SpiceWidgetsToolbar* _tmp12_;
	const gchar* _tmp13_;
	GtkStack* _tmp14_;
	SpiceWidgetsToolbar* _tmp15_;
	const gchar* _tmp16_;
	GtkStack* _tmp17_;
	SpiceWidgetsToolbar* _tmp18_;
	const gchar* _tmp19_;
	GtkStack* _tmp20_;
	SpiceWidgetsToolbar* _tmp21_;
	const gchar* _tmp22_;
	GtkStack* _tmp23_;
	SpiceWidgetsToolbar* _tmp24_;
	SpiceWindow* _tmp25_;
	SpiceWindow* _tmp26_;
	SpiceServicesHistoryManager* _tmp27_;
	SpiceServicesHistoryManager* _tmp28_;
#line 37 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_return_val_if_fail (slide_manager != NULL, NULL);
#line 37 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self = (SpiceDynamicToolbar*) g_object_new (object_type, NULL);
#line 38 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp0_ = _g_object_ref0 (slide_manager);
#line 38 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->manager);
#line 38 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->manager = _tmp0_;
#line 40 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_widget_set_valign ((GtkWidget*) self, GTK_ALIGN_START);
#line 42 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp1_ = (GtkStack*) gtk_stack_new ();
#line 42 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp1_);
#line 42 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->stack);
#line 42 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->stack = _tmp1_;
#line 43 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp2_ = self->priv->stack;
#line 43 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_set_transition_type (_tmp2_, GTK_STACK_TRANSITION_TYPE_SLIDE_DOWN);
#line 44 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp3_ = self->priv->stack;
#line 44 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_set_transition_duration (_tmp3_, (guint) 300);
#line 46 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp4_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 46 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_style_context_add_class (_tmp4_, "toolbar");
#line 47 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp5_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 47 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_style_context_add_class (_tmp5_, "spice-dynamic-toolbar");
#line 49 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp6_ = spice_widgets_text_toolbar_new (slide_manager);
#line 49 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp6_);
#line 49 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->text_bar);
#line 49 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->text_bar = (SpiceWidgetsToolbar*) _tmp6_;
#line 50 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp7_ = spice_widgets_shape_toolbar_new (slide_manager);
#line 50 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp7_);
#line 50 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->shape_bar);
#line 50 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->shape_bar = (SpiceWidgetsToolbar*) _tmp7_;
#line 51 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp8_ = spice_widgets_image_toolbar_new (slide_manager);
#line 51 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp8_);
#line 51 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->image_bar);
#line 51 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->image_bar = (SpiceWidgetsToolbar*) _tmp8_;
#line 52 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp9_ = spice_widgets_canvas_toolbar_new (slide_manager);
#line 52 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp9_);
#line 52 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->canvas_bar);
#line 52 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->canvas_bar = (SpiceWidgetsToolbar*) _tmp9_;
#line 53 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp10_ = spice_widgets_common_toolbar_new (slide_manager);
#line 53 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_object_ref_sink (_tmp10_);
#line 53 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->common_bar);
#line 53 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->common_bar = (SpiceWidgetsToolbar*) _tmp10_;
#line 55 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp11_ = self->priv->stack;
#line 55 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp12_ = self->priv->text_bar;
#line 55 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp13_ = self->priv->TEXT;
#line 55 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_add_named (_tmp11_, (GtkWidget*) _tmp12_, _tmp13_);
#line 56 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp14_ = self->priv->stack;
#line 56 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp15_ = self->priv->shape_bar;
#line 56 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp16_ = self->priv->SHAPE;
#line 56 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_add_named (_tmp14_, (GtkWidget*) _tmp15_, _tmp16_);
#line 57 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp17_ = self->priv->stack;
#line 57 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp18_ = self->priv->image_bar;
#line 57 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp19_ = self->priv->IMAGE;
#line 57 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_add_named (_tmp17_, (GtkWidget*) _tmp18_, _tmp19_);
#line 58 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp20_ = self->priv->stack;
#line 58 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp21_ = self->priv->canvas_bar;
#line 58 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp22_ = self->priv->CANVAS;
#line 58 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_stack_add_named (_tmp20_, (GtkWidget*) _tmp21_, _tmp22_);
#line 60 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp23_ = self->priv->stack;
#line 60 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp23_);
#line 61 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp24_ = self->priv->common_bar;
#line 61 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	gtk_container_add ((GtkContainer*) self, (GtkWidget*) _tmp24_);
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp25_ = spice_slide_manager_get_window (slide_manager);
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp26_ = _tmp25_;
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp27_ = spice_window_get_history_manager (_tmp26_);
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp28_ = _tmp27_;
#line 63 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_signal_connect_object (_tmp28_, "action-called", (GCallback) ___lambda117__spice_services_history_manager_action_called, self, 0);
#line 37 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	return self;
#line 507 "DynamicToolbar.c"
}

SpiceDynamicToolbar*
spice_dynamic_toolbar_new (SpiceSlideManager* slide_manager)
{
#line 37 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	return spice_dynamic_toolbar_construct (SPICE_TYPE_DYNAMIC_TOOLBAR, slide_manager);
#line 515 "DynamicToolbar.c"
}

void
spice_dynamic_toolbar_item_selected (SpiceDynamicToolbar* self,
                                     SpiceCanvasItem* item,
                                     gboolean new_item)
{
	SpiceWidgetsToolbar* _tmp13_;
#line 68 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_return_if_fail (self != NULL);
#line 69 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	if (item == NULL) {
#line 528 "DynamicToolbar.c"
		GtkStack* _tmp0_;
		const gchar* _tmp1_;
		SpiceWidgetsToolbar* _tmp2_;
		SpiceSlideManager* _tmp3_;
#line 70 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		_tmp0_ = self->priv->stack;
#line 70 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		_tmp1_ = self->priv->CANVAS;
#line 70 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		gtk_stack_set_visible_child_name (_tmp0_, _tmp1_);
#line 71 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		_tmp2_ = self->priv->canvas_bar;
#line 71 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		_tmp3_ = self->priv->manager;
#line 71 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		spice_widgets_toolbar_select_item (_tmp2_, item, _tmp3_->making_new_slide);
#line 545 "DynamicToolbar.c"
	} else {
#line 72 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
		if (SPICE_IS_TEXT_ITEM (item)) {
#line 549 "DynamicToolbar.c"
			GtkStack* _tmp4_;
			const gchar* _tmp5_;
			SpiceWidgetsToolbar* _tmp6_;
#line 73 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			_tmp4_ = self->priv->stack;
#line 73 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			_tmp5_ = self->priv->TEXT;
#line 73 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			gtk_stack_set_visible_child_name (_tmp4_, _tmp5_);
#line 74 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			_tmp6_ = self->priv->text_bar;
#line 74 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			spice_widgets_toolbar_select_item (_tmp6_, item, new_item);
#line 563 "DynamicToolbar.c"
		} else {
#line 75 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
			if (SPICE_IS_COLOR_ITEM (item)) {
#line 567 "DynamicToolbar.c"
				GtkStack* _tmp7_;
				const gchar* _tmp8_;
				SpiceWidgetsToolbar* _tmp9_;
#line 76 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				_tmp7_ = self->priv->stack;
#line 76 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				_tmp8_ = self->priv->SHAPE;
#line 76 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				gtk_stack_set_visible_child_name (_tmp7_, _tmp8_);
#line 77 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				_tmp9_ = self->priv->shape_bar;
#line 77 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				spice_widgets_toolbar_select_item (_tmp9_, item, new_item);
#line 581 "DynamicToolbar.c"
			} else {
#line 78 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
				if (SPICE_IS_IMAGE_ITEM (item)) {
#line 585 "DynamicToolbar.c"
					GtkStack* _tmp10_;
					const gchar* _tmp11_;
					SpiceWidgetsToolbar* _tmp12_;
#line 79 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
					_tmp10_ = self->priv->stack;
#line 79 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
					_tmp11_ = self->priv->IMAGE;
#line 79 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
					gtk_stack_set_visible_child_name (_tmp10_, _tmp11_);
#line 80 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
					_tmp12_ = self->priv->image_bar;
#line 80 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
					spice_widgets_toolbar_select_item (_tmp12_, item, new_item);
#line 599 "DynamicToolbar.c"
				}
			}
		}
	}
#line 83 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp13_ = self->priv->common_bar;
#line 83 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	spice_widgets_toolbar_select_item (_tmp13_, item, new_item);
#line 608 "DynamicToolbar.c"
}

static void
spice_dynamic_toolbar_class_init (SpiceDynamicToolbarClass * klass,
                                  gpointer klass_data)
{
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	spice_dynamic_toolbar_parent_class = g_type_class_peek_parent (klass);
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	g_type_class_adjust_private_offset (klass, &SpiceDynamicToolbar_private_offset);
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	G_OBJECT_CLASS (klass)->finalize = spice_dynamic_toolbar_finalize;
#line 621 "DynamicToolbar.c"
}

static void
spice_dynamic_toolbar_instance_init (SpiceDynamicToolbar * self,
                                     gpointer klass)
{
	gchar* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv = spice_dynamic_toolbar_get_instance_private (self);
#line 23 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp0_ = g_strdup ("text");
#line 23 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->TEXT = _tmp0_;
#line 24 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp1_ = g_strdup ("image");
#line 24 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->IMAGE = _tmp1_;
#line 25 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp2_ = g_strdup ("shape");
#line 25 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->SHAPE = _tmp2_;
#line 26 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_tmp3_ = g_strdup ("canvas");
#line 26 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self->priv->CANVAS = _tmp3_;
#line 650 "DynamicToolbar.c"
}

static void
spice_dynamic_toolbar_finalize (GObject * obj)
{
	SpiceDynamicToolbar * self;
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, SPICE_TYPE_DYNAMIC_TOOLBAR, SpiceDynamicToolbar);
#line 23 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_free0 (self->priv->TEXT);
#line 24 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_free0 (self->priv->IMAGE);
#line 25 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_free0 (self->priv->SHAPE);
#line 26 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_free0 (self->priv->CANVAS);
#line 28 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->manager);
#line 29 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->stack);
#line 31 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->text_bar);
#line 32 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->shape_bar);
#line 33 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->image_bar);
#line 34 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->canvas_bar);
#line 35 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	_g_object_unref0 (self->priv->common_bar);
#line 22 "../Spice-up-1.9.1/src/Widgets/DynamicToolbar.vala"
	G_OBJECT_CLASS (spice_dynamic_toolbar_parent_class)->finalize (obj);
#line 683 "DynamicToolbar.c"
}

static GType
spice_dynamic_toolbar_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (SpiceDynamicToolbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) spice_dynamic_toolbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SpiceDynamicToolbar), 0, (GInstanceInitFunc) spice_dynamic_toolbar_instance_init, NULL };
	GType spice_dynamic_toolbar_type_id;
	spice_dynamic_toolbar_type_id = g_type_register_static (gtk_box_get_type (), "SpiceDynamicToolbar", &g_define_type_info, 0);
	SpiceDynamicToolbar_private_offset = g_type_add_instance_private (spice_dynamic_toolbar_type_id, sizeof (SpiceDynamicToolbarPrivate));
	return spice_dynamic_toolbar_type_id;
}

GType
spice_dynamic_toolbar_get_type (void)
{
	static volatile gsize spice_dynamic_toolbar_type_id__once = 0;
	if (g_once_init_enter (&spice_dynamic_toolbar_type_id__once)) {
		GType spice_dynamic_toolbar_type_id;
		spice_dynamic_toolbar_type_id = spice_dynamic_toolbar_get_type_once ();
		g_once_init_leave (&spice_dynamic_toolbar_type_id__once, spice_dynamic_toolbar_type_id);
	}
	return spice_dynamic_toolbar_type_id__once;
}

